==> estateplat-common-1.1.0-20170306.034133-270-sources.jar: cn/gtmap/estateplat/model/server/core/OaSqr.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/3/3
 * @description 综合事务登记申请人信息
 */
@Table(name = "oa_sqr")
public class OaSqr {

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人ID
     */
    @Id
    private String sqrid;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人名称
     */
    private String sqrmc;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 证件种类
     */
    private String zjzl;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 证件号
     */
    private String zjh;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 通讯地址
     */
    private String txdz;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 出生日期
     */
    private String csrq;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 代理人名称
     */
    private String dlrmc;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 代理人电话
     */
    private String dlrdh;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 代理机构
     */
    private String dljg;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人类别
     */
    private String sqrlb;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 序号
     */
    private String xh;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 工作流实例ID
     */
    private String wiid;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 性别
     */
    private String xb;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 所属行业
     */
    private String sshy;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 联系电话
     */
    private String lxdh;

    public String getSqrid() {
        return sqrid;
    }

    public void setSqrid(String sqrid) {
        this.sqrid = sqrid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getCsrq() {
        return csrq;
    }

    public void setCsrq(String csrq) {
        this.csrq = csrq;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh;
    }

    public String getDljg() {
        return dljg;
    }

    public void setDljg(String dljg) {
        this.dljg = dljg;
    }

    public String getSqrlb() {
        return sqrlb;
    }

    public void setSqrlb(String sqrlb) {
        this.sqrlb = sqrlb;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }
}

==> estateplat-common-1.2.4-20220701.020735-1061-sources.jar: cn/gtmap/estateplat/model/server/core/OaSqr.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/3/3
 * @description 综合事务登记申请人信息
 */
@Table(name = "oa_sqr")
public class OaSqr implements Serializable,InsertVo{

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人ID
     */
    @Id
    private String sqrid;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人名称
     */
    private String sqrmc;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 证件种类
     */
    private String zjzl;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 证件号
     */
    private String zjh;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 通讯地址
     */
    private String txdz;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 出生日期
     */
    private String csrq;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 代理人名称
     */
    private String dlrmc;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 代理人电话
     */
    private String dlrdh;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 代理机构
     */
    private String dljg;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人类别
     */
    private String sqrlb;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 序号
     */
    private String xh;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 工作流实例ID
     */
    private String wiid;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 性别
     */
    private String xb;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 所属行业
     */
    private String sshy;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 联系电话
     */
    private String lxdh;

    public String getSqrid() {
        return sqrid;
    }

    public void setSqrid(String sqrid) {
        this.sqrid = sqrid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getCsrq() {
        return csrq;
    }

    public void setCsrq(String csrq) {
        this.csrq = csrq;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh;
    }

    public String getDljg() {
        return dljg;
    }

    public void setDljg(String dljg) {
        this.dljg = dljg;
    }

    public String getSqrlb() {
        return sqrlb;
    }

    public void setSqrlb(String sqrlb) {
        this.sqrlb = sqrlb;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }
}
